import { select, json, tsv, geoPath, geoOrthographic, zoom, event, scale, legend } from "d3";
import { feature } from 'topojson';
import { getQuery } from './getData.js';

const url = "https://api.data.netwerkdigitaalerfgoed.nl/datasets/ivo/NMVW/services/NMVW-39/sparql";
const query = `PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
    PREFIX dc: <http://purl.org/dc/elements/1.1/>
    PREFIX dct: <http://purl.org/dc/terms/>
    PREFIX skos: <http://www.w3.org/2004/02/skos/core#>
    PREFIX edm: <http://www.europeana.eu/schemas/edm/>
    PREFIX foaf: <http://xmlns.com/foaf/0.1/>
    PREFIX wgs84: <http://www.w3.org/2003/01/geo/wgs84_pos#>
    PREFIX geo: <http://www.opengis.net/ont/geosparql#>
    
    
    SELECT  ?typeLabel ?cho ?title ?lat ?long  (COUNT(?cho) AS ?choCount) WHERE {
      <https://hdl.handle.net/20.500.11840/termmaster13440> skos:narrower ?type .
      ?type skos:prefLabel ?typeLabel .
      ?cho dc:title ?title.
      
      ?cho edm:object ?type .
      
      ?place skos:exactMatch/wgs84:lat ?lat .
      ?place skos:exactMatch/wgs84:long ?long .     
    
    }
    
    ORDER BY DESC(?typeLabel)
    
    `;

getQuery(url, query).then(data => {
  console.log(data.results.bindings)
	init(data.results.bindings)
})

function init(places){
const svg = select('svg');
const projection = geoOrthographic();
const pathGenerator = geoPath().projection(projection);
const g = svg.append('g');
  
const category = places[0].typeLabel.value
  console.log(category);
  
  const cats = places.map(entry => entry.typeLabel.value);
  console.log(new Set(cats))
  
  const colorscale = d3.scaleOrdinal()
  	.domain(cats)
    .range(d3.schemeCategory10);
  

g.append('path')
  .attr('class', 'sphere')
  .attr('d', pathGenerator({type: 'Sphere'}))

	
svg.call(zoom().on('zoom', () => {
		g.attr('transform', event.transform);
}));
  
		const legend = svg.selectAll(".legend")
		.data(colorscale.domain())
		.enter().append("g")
		.attr("class", "legend")
		.attr("transform", function(d, i) { return "translate(0," + i * 20 + ")"; })


		legend.append("rect")
		.attr("x", 185 - 18)
		.attr("width", 18)
		.attr("height", 18)
		.style("fill", colorscale);

		legend.append("text")
		.attr("x", 185 - 24)
		.attr("y", 9)
		.attr("dy", ".35em")
		.style("text-anchor", "end")
		.text(function(d) { return d; })

Promise.all([
  tsv('https://unpkg.com/world-atlas@1.1.4/world/50m.tsv'),
  json('https://unpkg.com/world-atlas@1.1.4/world/50m.json')
]).then(([tsvData, topoJSONdata]) => {
  		const countryName = tsvData.reduce((accumulator, row) => {
  			accumulator[row.iso_n3] = row.name;
      		return accumulator;
      }, {});
  
			const country = feature(topoJSONdata, topoJSONdata.objects.countries);
        g.selectAll('path')
          .data(country.features)
          .enter()
          .append('path')
          .attr('class', 'country')
          .attr('d', d => pathGenerator(d))
        .append('title')
        	.text(d => countryName[d.id]);
  
  	g.selectAll('circle')
  		.data(places)
						  .enter().append("circle")
						  .attr("r", 1)
						  .attr("transform", function(d) {
							return "translate(" + projection([
							  d.long.value,
							  d.lat.value
							]) + ")";
						  })
							.style('fill', function(d){return colorscale(d)})
});
}
